@@ -591,7 +591,9 @@
 				return shareType === OC.Share.SHARE_TYPE_USER ||
 						shareType === OC.Share.SHARE_TYPE_GROUP ||
 						shareType === OC.Share.SHARE_TYPE_CIRCLE ||
-						shareType === OC.Share.SHARE_TYPE_ROOM;
+						shareType === OC.Share.SHARE_TYPE_ROOM ||
+						shareType === OC.Share.SHARE_TYPE_LINK ||
+						shareType === OC.Share.SHARE_TYPE_EMAIL;
 			});
 
 			if (shareTypes.length === 0) {
@@ -641,6 +643,7 @@
 				OCA.SpreedMe.app.signaling.syncRooms().then(function() {
 					roomsChannel.trigger('joinedRoom', OCA.SpreedMe.app.activeRoom);
 
+					OCA.SpreedMe.app._chatView.setRoom(OCA.SpreedMe.app.activeRoom);
 					OCA.SpreedMe.app._messageCollection.setRoomToken(OCA.SpreedMe.app.activeRoom.get('token'));
 					OCA.SpreedMe.app._messageCollection.receiveMessages();
 				});
