@@ -1,4 +1,4 @@
-/* global Marionette, $ */
+/* global Marionette */
 
 /**
  *
@@ -21,7 +21,7 @@
  *
  */
 
-(function(OC, OCA, Marionette, $) {
+(function(OC, OCA, Marionette) {
 
 	'use strict';
 
@@ -56,6 +56,7 @@
 
 		ui: {
 			'audioButton': '#mute',
+			'volumeIndicator': '#muteWrapper .volume-indicator',
 			'videoButton': '#hideVideo',
 			'screensharingButton': '#screensharing-button',
 			'screensharingMenu': '#screensharing-menu',
@@ -84,6 +85,8 @@
 			this._webrtc = options.webrtc;
 			this._sharedScreens = options.sharedScreens;
 
+			this._handleVolumeChangeBound = this._handleVolumeChange.bind(this);
+
 			this._audioAvailable = true;
 			this._videoAvailable = true;
 
@@ -92,7 +95,13 @@
 		},
 
 		setWebRtc: function(webrtc) {
+			if (this._webrtc && this._webrtc.webrtc) {
+				this._webrtc.webrtc.off('volumeChange', this._handleVolumeChangeBound);
+			}
+
 			this._webrtc = webrtc;
+
+			this._webrtc.webrtc.on('volumeChange', this._handleVolumeChangeBound);
 		},
 
 		setSharedScreens: function(sharedScreens) {
@@ -144,15 +153,47 @@
 		setAudioAvailable: function(audioAvailable) {
 			if (audioAvailable) {
 				this.getUI('audioButton').removeClass('no-audio-available');
+
+				this.getUI('volumeIndicator').removeClass('hidden');
 			} else {
 				this.getUI('audioButton').removeClass('audio-disabled icon-audio')
 					.addClass('no-audio-available icon-audio-off')
 					.attr('data-original-title', t('spreed', 'No audio'));
+
+				this.getUI('volumeIndicator').addClass('hidden');
 			}
 
 			this._audioAvailable = audioAvailable;
 		},
 
+		setSpeakingWhileMutedNotification: function(message) {
+			if (!message) {
+				this.getUI('audioButton').tooltip('dispose');
+
+				return;
+			}
+
+			this.getUI('audioButton').tooltip('hide')
+					.attr('data-original-title', message)
+					.tooltip('_fixTitle')
+					.tooltip({placement: 'bottom', trigger: 'manual'})
+					.tooltip('show');
+		},
+
+		_handleVolumeChange: function(currentVolume, threshold) {
+			// WebRTC volume goes from -100 (silence) to 0 (loudest sound in the
+			// system); for the volume indicator only sounds above the threshold
+			// are taken into account.
+			var currentVolumeProportion = 0;
+			if (currentVolume > threshold) {
+				currentVolumeProportion = (threshold - currentVolume) / threshold;
+			}
+
+			var maximumVolumeIndicatorHeight = this.getUI('volumeIndicator').parent().outerHeight() - (parseInt(this.getUI('volumeIndicator').css('bottom'), 10) * 2);
+
+			this.getUI('volumeIndicator').height(maximumVolumeIndicatorHeight * currentVolumeProportion);
+		},
+
 		toggleVideo: function() {
 			if (!this._videoAvailable) {
 				return;
@@ -320,7 +361,7 @@
 
 						if (extensionURL) {
 							var text = t('spreed', 'Screensharing extension is required to share your screen.');
-							var element = $('<a>').attr('href', extensionURL).attr('target','_blank').text(text);
+							var element = '<a href="' + extensionURL + '" target="_blank">' + escapeHTML(text) + '</a>';
 
 							OC.Notification.showTemporary(element, {isHTML: true});
 						} else {
@@ -350,4 +391,4 @@
 
 	OCA.SpreedMe.Views.MediaControlsView = MediaControlsView;
 
-})(OC, OCA, Marionette, $);
+})(OC, OCA, Marionette);
