@@ -33,22 +33,22 @@ OC.L10N.register(
     "Calls are disabled in this conversation." : "Puhelut on poistettu käytöstä tässä keskustelussa.",
     "Go to file" : "Siirry tiedostoon",
     "Share link" : "Jaa linkki",
+    "Copy link" : "Kopioi linkki",
     "Change password" : "Vaihda salasana",
     "Set password" : "Aseta salasana",
     "Name" : "Nimi",
     "Conversation name" : "Keskustelun nimi",
     "Rename" : "Nimeä uudelleen",
-    "Copy link" : "Kopioi linkki",
+    "Link copied!" : "Linkki kopioitu!",
     "Conversation with {name}" : "Keskustelu henkilön {name} kanssa",
     "Error occurred while setting password" : "Virhe salasanaa asettaessa",
-    "Link copied!" : "Linkki kopioitu!",
     "You" : "Sinä",
+    "Guest" : "Vieras",
     "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
     "New message …" : "Uusi viesti …",
     "Send" : "Lähetä",
     "You can not send messages, because the conversation is locked." : "Et voi lähettää viestejä, koska keskustelu on lukittu.",
     "The conversation is locked." : "Keskustelu on lukittu.",
-    "Guest" : "Vieras",
     "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
@@ -101,9 +101,6 @@ OC.L10N.register(
     "Favorited" : "Lisätty suosikkeihin",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
-    "Always notify" : "Ilmoita aina",
-    "Notify on @-mention" : "Ilmoita @-maininnoista",
-    "Never notify" : "Älä ilmoita koskaan",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Your screen" : "Sinun näyttösi",
@@ -128,7 +125,6 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["%n muu","%n muuta"],
     "{actor} invited you to {call}" : "{actor} kutsui sinut puheluun {call}",
     "New in Talk 6" : "Uutta Talkin 6-versiossa",
-    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edgeä ja Safaria voi nyt käyttää ääni- ja videopuheluissa",
     "The command does not exist" : "Komentoa ei ole olemassa",
     "Talk updates ✅" : "Talk-päivitykset ✅",
     "{actor} created the conversation" : "{actor} loi keskustelun",
@@ -191,14 +187,10 @@ OC.L10N.register(
     "{user} mentioned you in conversation {call}" : "{user} mainitsi sinut keskustelussa {call}",
     "A deleted user mentioned you in conversation {call}" : "Poistettu käyttäjä mainitsi sinut keskustelussa {call}",
     "A guest mentioned you in conversation {call}" : "Vieras mainitsi sinut keskustelussa {call}",
-    "%s invited you to a private conversation" : "%s kutsui sinut yksityiskeskusteluun",
     "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
-    "%s invited you to a group conversation: %s" : "%s kutsui sinut ryhmäkeskusteluun: %s",
     "{user} invited you to a group conversation: {call}" : "{user} kutsui sinut ryhmäkeskusteluun: {call}",
     "{user} wants to talk with you" : "{user} haluaa puhua kanssasi",
     "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
-    "{email} requested the password to access {file}" : "{email} pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
-    "Someone requested the password to access {file}" : "Joku pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
     "Conversation not found" : "Keskustelua ei löydy",
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
@@ -244,38 +236,32 @@ OC.L10N.register(
     "Delete server" : "Poista palvelin",
     "Add new server" : "Lisää uusi palvelin",
     "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Poistit kaikki STUN-palvelimet. Koska STUN-palvelinta tarvitaan lähes aina, lisäsimme oletuksena käytettävän STUN-palvelimen.",
-    "The TURN server settings are valid." : "TURN-palvelimen asetukset ovat kelvolliset.",
-    "Checking TURN server {server}" : "Tarkistetaan TURN-palvelinta {server}",
     "TURN server shared secret" : "TURN-palvelimen jaettu salausavain",
     "Test server" : "Testaa palvelin",
     "New public conversation" : "Uusi julkinen keskustelu",
     "New group conversation" : "Uusi ryhmäkeskustelu",
-    "Password request by %s" : "Salasanaa pyysi %s",
+    "Always notify" : "Ilmoita aina",
+    "Notify on @-mention" : "Ilmoita @-maininnoista",
+    "Never notify" : "Älä ilmoita koskaan",
     "_%n other guest_::_%n other guests_" : ["%n muu vieras","%n muuta vierasta"],
     ", " : ",",
-    "%s mentioned you in a private conversation" : "%s mainitsi sinut yksityskeskustelussa",
-    "%s mentioned you in a group conversation: %s" : "%s mainitsi sinut ryhmäkeskustelussa: %s",
-    "{user} mentioned you in a group conversation: {call}" : "{user} mainitsi sinut ryhmäkeskustelussa: {call}",
-    "%s mentioned you in a group conversation" : "%s mainitsi sinut ryhmäkeskustelussa",
-    "{user} mentioned you in a group conversation" : "{user} mainitsi sinut ryhmäkeskustelussa",
-    "You were mentioned in a group conversation by a deleted user: %s" : "Sinut mainittiin ryhmäkeskustelussa poistetun käyttäjän toimesta: %s",
-    "You were mentioned in a group conversation by a deleted user" : "Sinut mainittiin ryhmäkeskustelussa poistetun käyttäjän toimesta",
-    "A guest mentioned you in a group conversation: %s" : "Vieras mainitsi sinut ryhmäkeskustelussa: %s",
-    "A guest mentioned you in a group conversation: {call}" : "Vieras mainitsi sinut ryhmäkeskustelussa: {call}",
-    "A guest mentioned you in a group conversation" : "Vieras mainitsi sinut ryhmäkeskustelussa",
-    "%s invited you to a group conversation" : "%s kutsui sinut ryhmäkeskusteluun",
-    "{user} invited you to a group conversation" : "{user} kutsui sinut ryhmäkeskusteluun",
-    "A group call has started" : "Ryhmäpuhelu on alkanut",
-    "{email} requested the password to access a share" : "{email} pyysi salasanaa käyttääkseen jakoa",
-    "Unnamed conversation" : "Nimetön keskustelu",
-    "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
-    "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
     "Join now" : "Liity nyt",
     "{user} sent a message in a conversation" : "{user} lähetti viestin keskusteluun",
     "A deleted user sent a message in a conversation" : "Poistettu käyttäjä lähetti viestin keskusteluun",
     "A guest sent a message in a conversation" : "Vieras lähetti viestin keskusteluun",
     "{user} mentioned you in a conversation" : "{user} mainitsi sinut keskustelussa",
     "A deleted user mentioned you in a conversation" : "Poistettu käyttäjä mainitsi sinut keskustelussa",
-    "A guest mentioned you in a conversation" : "Vieras mainitsi sinut keskustelussa"
+    "A guest mentioned you in a conversation" : "Vieras mainitsi sinut keskustelussa",
+    "%s invited you to a private conversation" : "%s kutsui sinut yksityiskeskusteluun",
+    "%s invited you to a group conversation: %s" : "%s kutsui sinut ryhmäkeskusteluun: %s",
+    "%s invited you to a group conversation" : "%s kutsui sinut ryhmäkeskusteluun",
+    "{user} invited you to a group conversation" : "{user} kutsui sinut ryhmäkeskusteluun",
+    "A group call has started" : "Ryhmäpuhelu on alkanut",
+    "{email} requested the password to access {file}" : "{email} pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
+    "Someone requested the password to access {file}" : "Joku pyysi salasanaa voidakseen käsitellä tiedostoa {file}",
+    "Unnamed conversation" : "Nimetön keskustelu",
+    "Video & audio-conferencing using WebRTC" : "Video- ja äänipuheluita WebRTC:tä käyttäen",
+    "This call is password-protected" : "Tämä puhelu on salasanasuojattu",
+    "* Microsoft Edge and Safari can now be used to participate in audio and video calls" : "* Microsoft Edgeä ja Safaria voi nyt käyttää ääni- ja videopuheluissa"
 },
 "nplurals=2; plural=(n != 1);");
