@@ -21,21 +21,21 @@ OC.L10N.register(
     "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
     "Go to file" : "Pereiti į failą",
     "Share link" : "Dalinimosi nuoroda",
+    "Copy link" : "Kopijuoti nuorodą",
     "Change password" : "Pakeisti slaptažodį",
     "Set password" : "Nustatyti slaptažodį",
     "Conversation name" : "Pokalbio pavadinimas",
     "Rename" : "Pervadinti",
-    "Copy link" : "Kopijuoti nuorodą",
+    "Link copied!" : "Nuoroda nukopijuota!",
     "Conversation with {name}" : "Pokalbis su {name}",
     "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
-    "Link copied!" : "Nuoroda nukopijuota!",
     "You" : "Jūs",
+    "Guest" : "Svečias",
     "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
     "New message …" : "Nauja žinutė …",
     "Send" : "Siųsti",
     "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
     "The conversation is locked." : "Pokalbis užrakintas.",
-    "Guest" : "Svečias",
     "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
@@ -52,6 +52,7 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
     "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
+    "This conversation has ended" : "Šis pokalbis pasibaigė",
     "Mute audio" : "Nutildyti garsą",
     "Disable video" : "Išjungti vaizdą",
     "Share screen" : "Bendrinti ekraną",
@@ -80,8 +81,6 @@ OC.L10N.register(
     "Favorited" : "Pažymėtas svarbiu",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
-    "Always notify" : "Visada pranešti",
-    "Never notify" : "Niekada nepranešti",
     "Delete conversation" : "Ištrinti pokalbį",
     "Your screen" : "Jūsų ekranas",
     "Guest's screen" : "Svečio ekranas",
@@ -125,13 +124,11 @@ OC.L10N.register(
     "Private conversation" : "Privatus pokalbis",
     "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
     "{user} mentioned you in a private conversation" : "{user} jus paminėjo privačiame pokalbyje",
-    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
     "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
-    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
     "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
     "{user} wants to talk with you" : "{user} nori su jumis pasikalbėti",
-    "Someone requested the password to access {file}" : "Kažkas užklausė slaptažodį, kad gautų prieigą prie {file}",
     "Conversation not found" : "Pokalbis nerastas",
+    "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
     "TURN server URL" : "TURN serverio URL",
     "Delete this server" : "Ištrinti šį serverį",
     "STUN server URL" : "STUN serverio URL",
@@ -146,6 +143,7 @@ OC.L10N.register(
     "Commands" : "Komandos",
     "Command" : "Komanda",
     "Script" : "Scenarijus",
+    "General settings" : "Bendri nustatymai",
     "Saved" : "Įrašyta",
     "Add a new server" : "Pridėti naują serverį",
     "STUN servers" : "STUN serveriai",
@@ -160,26 +158,19 @@ OC.L10N.register(
     "Test server" : "Išbandyti serverį",
     "New public conversation" : "Naujas viešas pokalbis",
     "New group conversation" : "Naujas grupės pokalbis",
+    "Always notify" : "Visada pranešti",
+    "Never notify" : "Niekada nepranešti",
     "_%n other guest_::_%n other guests_" : ["ir dar %n svečias","ir dar %n svečiai","ir dar %n svečių","ir dar %n svečias"],
     ", " : ", ",
-    "%s mentioned you in a private conversation" : "%s jus paminėjo privačiame pokalbyje",
-    "%s mentioned you in a group conversation: %s" : "%s jus paminėjo grupės pokalbyje: %s",
-    "{user} mentioned you in a group conversation: {call}" : "{user} jus paminėjo grupės pokalbyje: {call}",
-    "%s mentioned you in a group conversation" : "%s jus paminėjo grupės pokalbyje",
-    "{user} mentioned you in a group conversation" : "{user} jus paminėjo grupės pokalbyje",
-    "You were mentioned in a group conversation by a deleted user: %s" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: %s",
-    "You were mentioned in a group conversation by a deleted user: {call}" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje: {call}",
-    "You were mentioned in a group conversation by a deleted user" : "Ištrintas naudotojas jus paminėjo grupės pokalbyje",
-    "A guest mentioned you in a group conversation: %s" : "Svečias jus paminėjo grupės pokalbyje: %s",
-    "A guest mentioned you in a group conversation: {call}" : "Svečias jus paminėjo grupės pokalbyje: {call}",
-    "A guest mentioned you in a group conversation" : "Svečias jus paminėjo grupės pokalbyje",
-    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
-    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
-    "{email} requested the password to access a share" : "{email} užklausė slaptažodžio, kad gautų prieigą prie viešinio",
-    "Unnamed conversation" : "Pokalbis be pavadinimo",
-    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu",
     "{user} sent a message in a conversation" : "{user} išsiuntė žinutę į pokalbį",
     "A deleted user sent a message in a conversation" : "Ištrintas naudotojas išsiuntė žinutę į pokalbį",
-    "A guest sent a message in a conversation" : "Svečias išsiuntė žinutę į pokalbį"
+    "A guest sent a message in a conversation" : "Svečias išsiuntė žinutę į pokalbį",
+    "%s invited you to a private conversation" : "%s jus pakvietė į privatų pokalbį",
+    "%s invited you to a group conversation: %s" : "%s jus pakvietė į grupės pokalbį: %s",
+    "%s invited you to a group conversation" : "%s jus pakvietė į grupės pokalbį",
+    "{user} invited you to a group conversation" : "{user} jus pakvietė į grupės pokalbį",
+    "Someone requested the password to access {file}" : "Kažkas užklausė slaptažodį, kad gautų prieigą prie {file}",
+    "Unnamed conversation" : "Pokalbis be pavadinimo",
+    "This call is password-protected" : "Šis skambutis yra apsaugotas slaptažodžiu"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
