@@ -51,6 +51,8 @@ class Manager {
 	private $userManager;
 	/** @var CommentsManager */
 	private $commentsManager;
+	/** @var TalkSession */
+	private $talkSession;
 	/** @var EventDispatcherInterface */
 	private $dispatcher;
 	/** @var ITimeFactory */
@@ -65,6 +67,7 @@ class Manager {
 								ISecureRandom $secureRandom,
 								IUserManager $userManager,
 								CommentsManager $commentsManager,
+								TalkSession $talkSession,
 								EventDispatcherInterface $dispatcher,
 								ITimeFactory $timeFactory,
 								IHasher $hasher,
@@ -74,6 +77,7 @@ class Manager {
 		$this->secureRandom = $secureRandom;
 		$this->userManager = $userManager;
 		$this->commentsManager = $commentsManager;
+		$this->talkSession = $talkSession;
 		$this->dispatcher = $dispatcher;
 		$this->timeFactory = $timeFactory;
 		$this->hasher = $hasher;
@@ -113,6 +117,11 @@ class Manager {
 			$lastActivity = $this->timeFactory->getDateTime($row['last_activity']);
 		}
 
+		$lobbyTimer = null;
+		if (!empty($row['lobby_timer'])) {
+			$lobbyTimer = $this->timeFactory->getDateTime($row['lobby_timer']);
+		}
+
 		$lastMessage = null;
 		if (!empty($row['comment_id'])) {
 			$lastMessage = $this->commentsManager->getCommentFromData(array_merge($row, [
@@ -126,7 +135,28 @@ class Manager {
 			]));
 		}
 
-		return new Room($this, $this->db, $this->secureRandom, $this->dispatcher, $this->timeFactory, $this->hasher, (int) $row['id'], (int) $row['type'], (int) $row['read_only'], $row['token'], $row['name'], $row['password'], (int) $row['active_guests'], $activeSince, $lastActivity, $lastMessage, (string) $row['object_type'], (string) $row['object_id']);
+		return new Room(
+			$this,
+			$this->db,
+			$this->secureRandom,
+			$this->dispatcher,
+			$this->timeFactory,
+			$this->hasher,
+			(int) $row['id'],
+			(int) $row['type'],
+			(int) $row['read_only'],
+			(int) $row['lobby_state'],
+			$row['token'],
+			$row['name'],
+			$row['password'],
+			(int) $row['active_guests'],
+			$activeSince,
+			$lastActivity,
+			$lastMessage,
+			$lobbyTimer,
+			(string) $row['object_type'],
+			(string) $row['object_id']
+		);
 	}
 
 	/**
@@ -135,12 +165,26 @@ class Manager {
 	 * @return Participant
 	 */
 	public function createParticipantObject(Room $room, array $row): Participant {
-		$lastMention = null;
-		if (!empty($row['last_mention'])) {
-			$lastMention = $this->timeFactory->getDateTime($row['last_mention']);
+		$lastJoinedCall = null;
+		if (!empty($row['last_joined_call'])) {
+			$lastJoinedCall = $this->timeFactory->getDateTime($row['last_joined_call']);
 		}
 
-		return new Participant($this->db, $room, (string) $row['user_id'], (int) $row['participant_type'], (int) $row['last_ping'], (string) $row['session_id'], (int) $row['in_call'], (int) $row['notification_level'], (bool) $row['favorite'], $lastMention);
+		return new Participant(
+			$this->db,
+			$this->config,
+			$room,
+			(string) $row['user_id'],
+			(int) $row['participant_type'],
+			(int) $row['last_ping'],
+			(string) $row['session_id'],
+			(int) $row['in_call'],
+			(int) $row['notification_level'],
+			(bool) $row['favorite'],
+			(int) $row['last_read_message'],
+			(int) $row['last_mention_message'],
+			$lastJoinedCall
+		);
 	}
 
 	/**
@@ -663,14 +707,19 @@ class Manager {
 
 			if ($otherParticipant === '' && $room->getName() !== '') {
 				$user = $this->userManager->get($room->getName());
-				$otherParticipant = $user instanceof IUser ? $user->getDisplayName() : $participantId;
+				$otherParticipant = $user instanceof IUser ? $user->getDisplayName() : $this->l->t('Deleted user (%s)', $room->getName());
 			}
 
 			return $otherParticipant;
 		}
 
 		try {
-			$room->getParticipant($userId);
+			if ($userId === '') {
+				$sessionId = $this->talkSession->getSessionForRoom($room->getToken());
+				$room->getParticipantBySession($sessionId);
+			} else {
+				$room->getParticipant($userId);
+			}
 		} catch (ParticipantNotFoundException $e) {
 			// Do not leak the name of rooms the user is not a part of
 			return $this->l->t('Private conversation');
