@@ -49,6 +49,10 @@ class Room {
 	public const READ_WRITE = 0;
 	public const READ_ONLY = 1;
 
+	public const START_CALL_EVERYONE = 0;
+	public const START_CALL_USERS = 1;
+	public const START_CALL_MODERATORS = 2;
+
 	public const PARTICIPANT_REMOVED = 'remove';
 	public const PARTICIPANT_LEFT = 'leave';
 
@@ -71,6 +75,10 @@ class Room {
 	private $type;
 	/** @var int */
 	private $readOnly;
+	/** @var int */
+	private $lobbyState;
+	/** @var \DateTime|null */
+	private $lobbyTimer;
 	/** @var string */
 	private $token;
 	/** @var string */
@@ -104,6 +112,7 @@ class Room {
 								int $id,
 								int $type,
 								int $readOnly,
+								int $lobbyState,
 								string $token,
 								string $name,
 								string $password,
@@ -111,6 +120,7 @@ class Room {
 								\DateTime $activeSince = null,
 								\DateTime $lastActivity = null,
 								IComment $lastMessage = null,
+								\DateTime $lobbyTimer = null,
 								string $objectType = '',
 								string $objectId = '') {
 		$this->manager = $manager;
@@ -122,6 +132,7 @@ class Room {
 		$this->id = $id;
 		$this->type = $type;
 		$this->readOnly = $readOnly;
+		$this->lobbyState = $lobbyState;
 		$this->token = $token;
 		$this->name = $name;
 		$this->password = $password;
@@ -129,6 +140,7 @@ class Room {
 		$this->activeSince = $activeSince;
 		$this->lastActivity = $lastActivity;
 		$this->lastMessage = $lastMessage;
+		$this->lobbyTimer = $lobbyTimer;
 		$this->objectType = $objectType;
 		$this->objectId = $objectId;
 	}
@@ -145,6 +157,22 @@ class Room {
 		return $this->readOnly;
 	}
 
+	public function getLobbyState(): int {
+		$this->validateTimer();
+		return $this->lobbyState;
+	}
+
+	public function getLobbyTimer(): ?\DateTime {
+		$this->validateTimer();
+		return $this->lobbyTimer;
+	}
+
+	protected function validateTimer(): void {
+		if ($this->lobbyTimer !== null && $this->lobbyTimer < $this->timeFactory->getDateTime()) {
+			$this->setLobby(Webinary::LOBBY_NONE, null, true);
+		}
+	}
+
 	public function getToken(): string {
 		return $this->token;
 	}
@@ -497,6 +525,56 @@ class Room {
 		return true;
 	}
 
+	/**
+	 * @param int $newState Currently it is only allowed to change between
+	 * 						`Webinary::LOBBY_NON_MODERATORS` and `Webinary::LOBBY_NONE`
+	 * 						Also it's not allowed in one-to-one conversations,
+	 * 						file conversations and password request conversations.
+	 * @param \DateTime|null $dateTime
+	 * @param bool $timerReached
+	 * @return bool True when the change was valid, false otherwise
+	 */
+	public function setLobby(int $newState, ?\DateTime $dateTime, bool $timerReached = false): bool {
+		$oldState = $this->lobbyState;
+
+		if (!in_array($this->getType(), [self::GROUP_CALL, self::PUBLIC_CALL], true)) {
+			return false;
+		}
+
+		if ($this->getObjectType() !== '') {
+			return false;
+		}
+
+		if (!in_array($newState, [Webinary::LOBBY_NON_MODERATORS, Webinary::LOBBY_NONE], true)) {
+			return false;
+		}
+
+		$this->dispatcher->dispatch(self::class . '::preSetLobbyState', new GenericEvent($this, [
+			'newState' => $newState,
+			'oldState' => $oldState,
+			'lobbyTimer' => $dateTime,
+			'timerReached' => $timerReached,
+		]));
+
+		$query = $this->db->getQueryBuilder();
+		$query->update('talk_rooms')
+			->set('lobby_state', $query->createNamedParameter($newState, IQueryBuilder::PARAM_INT))
+			->set('lobby_timer', $query->createNamedParameter($dateTime, IQueryBuilder::PARAM_DATE))
+			->where($query->expr()->eq('id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+		$query->execute();
+
+		$this->lobbyState = $newState;
+
+		$this->dispatcher->dispatch(self::class . '::postSetLobbyState', new GenericEvent($this, [
+			'newState' => $newState,
+			'oldState' => $oldState,
+			'lobbyTimer' => $dateTime,
+			'timerReached' => $timerReached,
+		]));
+
+		return true;
+	}
+
 	public function ensureOneToOneRoomIsFilled(): void {
 		if ($this->getType() !== self::ONE_TO_ONE_CALL) {
 			return;
@@ -524,6 +602,11 @@ class Room {
 			'users' => $participants,
 		]));
 
+		$lastMessage = 0;
+		if ($this->getLastMessage() instanceof IComment) {
+			$lastMessage = (int) $this->getLastMessage()->getId();
+		}
+
 		$query = $this->db->getQueryBuilder();
 		$query->insert('talk_participants')
 			->values(
@@ -533,6 +616,7 @@ class Room {
 					'participant_type' => $query->createParameter('participant_type'),
 					'room_id' => $query->createNamedParameter($this->getId()),
 					'last_ping' => $query->createNamedParameter(0, IQueryBuilder::PARAM_INT),
+					'last_read_message' => $query->createNamedParameter($lastMessage, IQueryBuilder::PARAM_INT),
 				]
 			);
 
@@ -779,6 +863,11 @@ class Room {
 			throw new InvalidPasswordException();
 		}
 
+		$lastMessage = 0;
+		if ($this->getLastMessage() instanceof IComment) {
+			$lastMessage = (int) $this->getLastMessage()->getId();
+		}
+
 		$sessionId = $this->secureRandom->generate(255);
 		while (!$this->db->insertIfNotExist('*PREFIX*talk_participants', [
 			'user_id' => '',
@@ -786,6 +875,7 @@ class Room {
 			'last_ping' => 0,
 			'session_id' => $sessionId,
 			'participant_type' => Participant::GUEST,
+			'last_read_message' => $lastMessage,
 		], ['session_id'])) {
 			$sessionId = $this->secureRandom->generate(255);
 		}
@@ -813,6 +903,13 @@ class Room {
 			->set('in_call', $query->createNamedParameter($flags, IQueryBuilder::PARAM_INT))
 			->where($query->expr()->eq('session_id', $query->createNamedParameter($sessionId)))
 			->andWhere($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
+
+		if ($flags !== Participant::FLAG_DISCONNECTED) {
+			$query->set('last_joined_call', $query->createNamedParameter(
+				$this->timeFactory->getDateTime(), IQueryBuilder::PARAM_DATE
+			));
+		}
+
 		$query->execute();
 
 		if ($flags !== Participant::FLAG_DISCONNECTED) {
@@ -949,18 +1046,18 @@ class Room {
 	}
 
 	/**
-	 * @param int $lastPing When the last ping is older than the given timestamp, the user is ignored
+	 * @param null|\DateTime $maxLastJoined When the "last joined call" is older than the given DateTime, the user is ignored
 	 * @return string[]
 	 */
-	public function getParticipantUserIds(int $lastPing = 0): array {
+	public function getParticipantUserIds(\DateTime $maxLastJoined = null): array {
 		$query = $this->db->getQueryBuilder();
 		$query->select('user_id')
 			->from('talk_participants')
 			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->nonEmptyString('user_id'));
 
-		if ($lastPing > 0) {
-			$query->andWhere($query->expr()->gt('last_ping', $query->createNamedParameter($lastPing, IQueryBuilder::PARAM_INT)));
+		if ($maxLastJoined instanceof \DateTimeInterface) {
+			$query->andWhere($query->expr()->gte('last_joined_call', $query->createNamedParameter($maxLastJoined, IQueryBuilder::PARAM_DATE)));
 		}
 
 		$result = $query->execute();
@@ -1105,10 +1202,10 @@ class Room {
 		return (int) ($row['num_participants'] ?? 0);
 	}
 
-	public function markUsersAsMentioned(array $userIds, \DateTime $time): void {
+	public function markUsersAsMentioned(array $userIds, int $messageId): void {
 		$query = $this->db->getQueryBuilder();
 		$query->update('talk_participants')
-			->set('last_mention', $query->createNamedParameter($time, 'datetime'))
+			->set('last_mention_message', $query->createNamedParameter($messageId, IQueryBuilder::PARAM_INT))
 			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->in('user_id', $query->createNamedParameter($userIds, IQueryBuilder::PARAM_STR_ARRAY)));
 		$query->execute();
